@@ -497,7 +497,7 @@ class PendingDeposits:
             return
         trustline_found = False
         for balance in account["balances"]:
-            if balance.get("asset_type") == "native":
+            if balance.get("asset_type") in ["native", "liquidity_pool_shares"]:
                 continue
             if (
                 balance["asset_code"] == transaction.asset.code
